@@ -7,8 +7,8 @@ import tables
 from mock import patch
 
 
-TEST_DATA_FILE = 'test_data/DAT000000'
-TEST_EXPECTED_FILE = 'test_data/corsika.h5'
+TEST_DATA_FILE = 'test_data/1_2/DAT000000'
+TEST_EXPECTED_FILE = 'test_data/1_2/corsika.h5'
 STORE_SCRIPT = 'store_corsika_data {source} {destination}'
 
 
